@@ -4,4 +4,4 @@ no need to specify exact modules.
 """
 
 from .qc_decorator import qc
-from .checker import for_all, Checker, Result, CheckError, ReturnedFalse
+from .checker import *
