@@ -63,6 +63,8 @@ def unique(method, self, *args):
     for item in method(self, *args):
         if isinstance(item, list):
             s_item = tuple(item)
+        elif isinstance(item, dict):
+            s_item = tuple(item.items())
         else:
             s_item = item
 
